@@ -654,7 +654,7 @@ def show_conflict(f1, f2, path):
 			p2+= "("+getdatestr(f2)+")"
 
 	print("CONFLICT detected on: "+tostr(path))
-	print_action("", "LEFT DIR CHANGE", "   ", "RIGHT DIR CHANGE")
+	print_action("", "LOCAL CHANGE", "   ", "REMOTE CHANGE")
 	print_action("", p1, "   ", p2)
 	print()
 
@@ -678,10 +678,10 @@ def ask_conflict(f1, f2, path, tokeep):
 			sys.exit("Error: Conflict found in batch mode. Exiting.")
 
 		if resp!=None:
-			print("	1	Keep left version")
-			print("	2	Keep right version")
-			print("	1a	Keep left version for all")
-			print("	2a	Keep right version for all")
+			print("	1	Keep local version")
+			print("	2	Keep remote version")
+			print("	1a	Keep local version for all")
+			print("	2a	Keep remote version for all")
 			print("  Please note: you will be able to confirm the actions later.\n")
 
 		resp = myinput("Which one do I keep? [1/2/1a/2a/Quit/Help] ")
@@ -887,6 +887,7 @@ def usage():
 	usage+= "	-c		Check that dirs are identical in the end\n"
 	usage+= "	-d		Make the dirs if they do not exist\n"
 	usage+= "	-n		Dry run: report changes without applying them\n"
+	usage+= "	-y		Apply the changes when no conflict\n"
 	usage+= "	-p PORT		Port for SSH\n"
 	usage+= "	-o SSHARGS	Custom options for SSH\n"
 	printerr(usage)
@@ -895,13 +896,13 @@ def usage():
 
 #### process commandline args
 try:
-	opts, args = getopt.gnu_getopt(sys.argv[1:], "vcibdnp:o:")
+	opts, args = getopt.gnu_getopt(sys.argv[1:], "vcibdnyp:o:")
 except getopt.GetoptError as err:
 	printerr(err)
 	usage()
 	sys.exit(2)
 
-verbose = check = ignoreperms = batch = mkdirp = dry_run = False
+verbose = check = ignoreperms = batch = mkdirp = dry_run = yes = False
 sshport = None
 sshargs = ""
 for o, a in opts:
@@ -917,6 +918,8 @@ for o, a in opts:
 		sshargs = a
 	elif o == "-b":
 		batch = True
+	elif o == "-y":
+		yes = True
 	elif o == "-d":
 		mkdirp = True
 	elif o == "-n":
@@ -1169,7 +1172,7 @@ if len(mkdir1)==0 and len(moves1)==0 and len(rm1)==0 and len(rmdirs1)==0 and len
 
 if len(conflicts) > 0: print_line()
 print()
-print_action("ACTION", "(LEFT DIR CONTENT)", "   ", "(RIGHT DIR CONTENT)")
+print_action("ACTION", "(LOCAL CONTENT)", "   ", "(REMOTE CONTENT)")
 print()
 print_actions(2, mkdir2,moves2,rm2,rmdirs2, copy12,sync12)
 print_actions(1, mkdir1,moves1,rm1,rmdirs1, copy21,sync21)
@@ -1179,7 +1182,7 @@ print("Todo in "+args[0]+": "+get_dir_summary(mkdir1,moves1,rm1,rmdirs1, copy21,
 print("Todo in "+args[1]+": "+get_dir_summary(mkdir2,moves2,rm2,rmdirs2, copy12,sync12))
 
 resp = "none"
-if batch: resp = "y"
+if batch or yes: resp = "y"
 elif dry_run: resp = "n"
 
 while resp != "y" and resp != "n":
